@@ -1,8 +1,8 @@
-#@ MODIF Utmess Utilitai  DATE 16/02/2010   AUTEUR COURTOIS M.COURTOIS 
+#@ MODIF Utmess Utilitai  DATE 14/03/2011   AUTEUR COURTOIS M.COURTOIS 
 # -*- coding: iso-8859-1 -*-
 #            CONFIGURATION MANAGEMENT OF EDF VERSION
 # ======================================================================
-# COPYRIGHT (C) 1991 - 2004  EDF R&D                  WWW.CODE-ASTER.ORG
+# COPYRIGHT (C) 1991 - 2011  EDF R&D                  WWW.CODE-ASTER.ORG
 # THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
 # IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
 # THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
@@ -28,16 +28,20 @@ import re
 # protection pour eficas
 try:
     import aster
+    from aster import error
     aster_exists = True
     from Messages.context_info import message_context_concept
-    AsterError = aster.error
 except:
     aster_exists = False
-    class AsterError(Exception): pass
+    class error(Exception):
+        pass
 
 def _(s):
     return s
 
+from Noyau.N_types import force_list
+
+
 MAXLENGTH = 132
 
 contacter_assistance = """
@@ -46,13 +50,21 @@ Veuillez contacter votre assistance technique."""
 
 # voir en fin de fin les faux appels  UTMESS pour la vrification des messages
 
-class MessageError(Exception):
-    """Arguments = (id_message, vali, valr, valk)."""
-    def __init__(self, id_message, valk=(), vali=(), valr=()):
-        self.id_message = id_message
-        self.valk = valk
-        self.vali = vali
-        self.valr = valr
+
+def list_unit(code):
+    """Retourne la liste des noms de fichiers (logiques) sur lesquels doit
+    etre imprim le message.
+    """
+    #IDF  = INDEX('EFIDASXZ', ...)
+    #'Z' (IDF=8) = LEVEE D'EXCEPTION
+    d = {
+        'E' : ('ERREUR', 'MESSAGE', 'RESULTAT'),
+        'I' : ('MESSAGE',),
+        'A' : ('MESSAGE', 'RESULTAT'),
+    }
+    d['F'] = d['S'] = d['Z'] = d['E']
+    d['X'] = d['A']
+    return d.get(code, d['F'])
 
 
 class MESSAGE_LOGGER:
@@ -99,9 +111,13 @@ class MESSAGE_LOGGER:
             code  : 'A', 'E', 'S', 'F', 'I'
             idmess : identificateur du message
             valk, vali, valr : liste des chaines, entiers ou rels.
-        Si exception==True, on lve une exception en cas d'erreur.
+        Si exception==True, on lve une exception en cas d'erreur, sinon
+        c'est l'appelant qui devra s'en charger (dans le C a priori).
         'print_as' : cf. print_buffer_content.
         """
+        # le '+' n'a pas de sens pour les messages 'I'.
+        if code == "I+":
+            code = "I"
         # rcupration du texte du message
         dictmess = self.get_message(code, idmess, valk, vali, valr)
         
@@ -117,7 +133,7 @@ class MESSAGE_LOGGER:
             self.print_buffer_content(print_as, cc)
 
             if exception and code[0] in ('S', 'F'):
-                raise AsterError, ' <EXCEPTION LEVEE> %s' % idmess
+                raise error(idmess, valk, vali, valr)
         
         return None
 
@@ -126,7 +142,7 @@ class MESSAGE_LOGGER:
         """Construit le dictionnaire de formatage du message.
         """
         # homognisation : uniquement des tuples + strip des chaines de caractres
-        valk, vali, valr = map(force_enum, (valk, vali, valr))
+        valk, vali, valr = map(force_list, (valk, vali, valr))
         valk    = [k.strip() for k in valk]
         
         # variables passes au message
@@ -276,7 +292,7 @@ Exception : %s
         dglob['context_info'] = ''.join(dglob['liste_context'])
         
         # liste des units d'impression en fonction du type de message
-        l_unit = self.list_unit(print_as or dglob['code'], dglob['id_message'])
+        l_unit = list_unit(print_as or dglob['code'])
         
         # texte final et impression
         txt = self.format_message(dglob)
@@ -493,22 +509,6 @@ du calcul ont t sauves dans la base jusqu'au moment de l'arret."""),
         return clean_string(os.linesep.join(l_txt))
 
 
-    def list_unit(self, code, idmess):
-        """Retourne la liste des noms de fichiers (logiques) sur lesquels doit
-        etre imprim le message.
-        """
-        #IDF  = INDEX('EFIDASXZ', ...)
-        #'Z' (IDF=8) = LEVEE D'EXCEPTION
-        d = {
-            'E' : ('ERREUR', 'MESSAGE', 'RESULTAT'),
-            'I' : ('MESSAGE',),
-            'A' : ('MESSAGE', 'RESULTAT'),
-        }
-        d['F'] = d['S'] = d['Z'] = d['E']
-        d['X'] = d['A']
-        return d.get(code, d['F'])
-
-
     def get_type_message(self, code):
         """Retourne le type du message affich.
         En cas d'erreur, si on lve une exception au lieu de s'arreter,
@@ -536,7 +536,7 @@ du calcul ont t sauves dans la base jusqu'au moment de l'arret."""),
         # tout dans un try/except car c'est du bonus, il ne faudrait pas planter !
         try:
             if ctxt_msg.has_key('CONCEPT'):
-                l_co =  [dicarg[arg] for arg in force_enum(ctxt_msg['CONCEPT'])]
+                l_co =  [dicarg[arg] for arg in force_list(ctxt_msg['CONCEPT'])]
                 for co in l_co:
                     msg.append(message_context_concept(co))
         except:
@@ -574,15 +574,6 @@ def clean_string(chaine):
     return ''.join(txt)
 
 
-def force_enum(obj):
-    """Retourne `obj` si c'est une liste ou un tuple,
-    sinon retourne [obj,]
-    """
-    if type(obj) not in (list, tuple):
-        obj = [obj,]
-    return obj
-
-
 def maximize_lines(l_fields, maxlen, sep):
     """Construit des lignes dont la longueur est au plus de `maxlen` caractres.
     Les champs sont assembls avec le sparateur `sep`.
@@ -621,8 +612,7 @@ def cut_long_lines(txt, maxlen, sep=os.linesep,
 def copy_text_to(text, files):
     """Imprime le texte dans les fichiers.
     """
-    if type(files) not in (list, tuple):
-        files = [files,]
+    files = force_list(files)
     for f in files:
         assert type(f) in (str, file)
         if type(f) == file:
@@ -658,13 +648,21 @@ def UTMESS(code, idmess, valk=(), vali=(), valr=(), print_as=None, cc=None):
     MessageLog(code, idmess, valk, vali, valr, exception=True, print_as=print_as, cc=cc)
 
 
-def ASSERT(condition):
+def ASSERT(condition, message=""):
     """Remonter un assert dans un message.
     """
     if condition:
         return
     stack = traceback.format_stack(limit=10)
-    UTMESS('F', 'DVP_9', valk=(''.join(stack[:-1]),))
+    UTMESS('F', 'DVP_9', valk=[(''.join(stack[:-1]),), message])
+
+
+def message_exception(code, exc):
+    """Retourne le message associ  une exception aster.error
+    tel qu'il aurait t imprim par UTMESS selon la valeur de
+    `code` ('I', 'A', 'S', 'F', 'Z'...)."""
+    return MessageLog.GetText(code, exc.id_message,
+                              exc.valk, exc.vali, exc.valr)
 
 
 def MasquerAlarme(idmess):
@@ -687,6 +685,9 @@ def RetablirAlarme(idmess):
 # faux appels  UTMESS
 def __fake__():
     UTMESS('I', 'SUPERVIS_40')    # surcharge mis par asrun
+    UTMESS('I', 'SUPERVIS_96')    # mis depuis le C (inisig)
+    UTMESS('I', 'SUPERVIS_97')    # mis depuis le C (inisig)
+    UTMESS('I', 'GENERIC_1')      # dans des tests pour traiter les exceptions
     UTMESS('I', 'CATAMESS_6')
     UTMESS('I', 'CATAMESS_41')
     UTMESS('I', 'CATAMESS_55')    # pour u2mesg.f
@@ -697,10 +698,14 @@ def __fake__():
     UTMESS('I', 'CATAMESS_90')
     UTMESS('I', 'CATAMESS_91')
     UTMESS('I', 'CATAMESS_92')
+    # appel par lev d'exception
     UTMESS('I', 'MISS0_3')
     UTMESS('I', 'MISS0_5')
     UTMESS('I', 'MISS0_6')
     UTMESS('I', 'MISS0_7')
     UTMESS('I', 'MISS0_8')
+    UTMESS('I', 'MISS0_9')
+    UTMESS('I', 'MISS0_11')
+    UTMESS('I', 'MISS0_17')
 
 
