@@ -1,4 +1,4 @@
-#@ MODIF t_fonction Utilitai  DATE 27/05/2010   AUTEUR MACOCCO K.MACOCCO 
+#@ MODIF t_fonction Utilitai  DATE 17/11/2010   AUTEUR MACOCCO K.MACOCCO 
 # -*- coding: iso-8859-1 -*-
 #            CONFIGURATION MANAGEMENT OF EDF VERSION
 # ======================================================================
@@ -391,7 +391,7 @@ class t_fonction :
        vale_y=self.vale_y[:2**n]
     elif methode=='PROL_ZERO'  :
        vale_y=self.vale_y
-       if len(self.vale_y) < 2**(n + 1):
+       if len(self.vale_y) > 2**n:
           vale_y=array(self.vale_y)
           vale_y = concatenate( (vale_y, zeros(2**(n+1)-len(self.vale_x))) )
     elif   methode=='COMPLET'  : 
@@ -447,7 +447,7 @@ class t_fonction_c(t_fonction) :
     else :
        if methode=='PROL_ZERO' :
           fonc_temp=self.vale_y
-          if len(self.vale_y) < 2**(n + 1):
+          if len(self.vale_y) > 2**n:
              fonc_temp = concatenate( (self.vale_y, zeros(2**(n+1)-len(self.vale_x)))  )
        elif methode=='TRONCATURE' :
           fonc_temp=self.vale_y[:2**n]
