@@ -30,14 +30,14 @@ from Noyau.N_utils import repr_float
 import Validation
 import CONNECTOR
 
-# Attention : les classes ASSD,.... peuvent etre surcharges
-# dans le package Accas. Il faut donc prendre des prcautions si
+# Attention : les classes ASSD,.... peuvent etre surchargées
+# dans le package Accas. Il faut donc prendre des précautions si
 # on utilise les classes du Noyau pour faire des tests (isxxxx, ...)
-# Si on veut crer des objets comme des CO avec les classes du noyau
+# Si on veut créer des objets comme des CO avec les classes du noyau
 # ils n'auront pas les conportements des autres packages (pb!!!)
-# Il vaut mieux les importer d'Accas mais problme d'import circulaire,
-# on ne peut pas les importer au dbut.
-# On fait donc un import local quand c'est ncessaire (peut occasionner
+# Il vaut mieux les importer d'Accas mais problème d'import circulaire,
+# on ne peut pas les importer au début.
+# On fait donc un import local quand c'est nécessaire (peut occasionner
 # des pbs de prformance).
 from Noyau.N_ASSD import ASSD,assd
 from Noyau.N_GEOM import GEOM,geom
@@ -53,11 +53,12 @@ from I_VALIDATOR import ValError,listProto
 
 class MCSIMP(I_OBJECT.OBJECT):
 
+
   def isvalid(self,cr='non'):
       if self.state == 'unchanged':
         return self.valid
       for type_permis in self.definition.type:
-          if type_permis.__class__.__name__ == 'Matrice' :
+          if hasattr(type_permis, "__class__") and type_permis.__class__.__name__ == 'Matrice':
              self.monType=type_permis
              return self.valideMatrice(cr=cr)
       return Validation.V_MCSIMP.MCSIMP.isvalid(self,cr=cr)
@@ -79,14 +80,14 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def GetText(self):
     """
-        Retourne le texte  afficher dans l'arbre reprsentant la valeur de l'objet
-        point par self
+        Retourne le texte a afficher dans l'arbre représentant la valeur de l'objet
+        pointé par self
     """
 
     if self.valeur == None : 
       return None
     elif type(self.valeur) == types.FloatType : 
-      # Traitement d'un flottant isol
+      # Traitement d'un flottant isolé
       txt = str(self.valeur)
       clefobj=self.GetNomConcept()
       if self.jdc.appli.appliEficas.dict_reels.has_key(clefobj):
@@ -127,7 +128,7 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def getval(self):
     """ 
-       Retourne une chane de caractre reprsentant la valeur de self 
+       Retourne une chaîne de caractère représentant la valeur de self 
     """
     val=self.valeur
     if type(val) == types.FloatType : 
@@ -152,7 +153,7 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def wait_co(self):
     """
-        Mthode boolenne qui retourne 1 si l'objet attend un objet ASSD 
+        Méthode booléenne qui retourne 1 si l'objet attend un objet ASSD 
         qui n'existe pas encore (type CO()), 0 sinon
     """
     for typ in self.definition.type:
@@ -163,8 +164,8 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def wait_assd(self):
     """ 
-        Mthode boolenne qui retourne 1 si le MCS attend un objet de type ASSD 
-        ou driv, 0 sinon
+        Méthode booléenne qui retourne 1 si le MCS attend un objet de type ASSD 
+        ou dérivé, 0 sinon
     """
     for typ in self.definition.type:
       if type(typ) == types.ClassType or isinstance(typ,type):
@@ -174,7 +175,7 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def wait_assd_or_geom(self):
     """ 
-         Retourne 1 si le mot-cl simple attend un objet de type
+         Retourne 1 si le mot-clé simple attend un objet de type
          assd, ASSD, geom ou GEOM
          Retourne 0 dans le cas contraire
     """
@@ -186,7 +187,7 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def wait_geom(self):
     """ 
-         Retourne 1 si le mot-cl simple attend un objet de type GEOM
+         Retourne 1 si le mot-clé simple attend un objet de type GEOM
          Retourne 0 dans le cas contraire
     """
     for typ in self.definition.type:
@@ -196,7 +197,7 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def wait_TXM(self):
     """ 
-         Retourne 1 si le mot-cl simple attend un objet de type TXM
+         Retourne 1 si le mot-clé simple attend un objet de type TXM
          Retourne 0 dans le cas contraire
     """
     for typ in self.definition.type:
@@ -226,7 +227,7 @@ class MCSIMP(I_OBJECT.OBJECT):
       lval=listProto.adapt(valeur)
       if lval is None:
          valid=0
-         mess="None n'est pas une valeur autorise"
+         mess="None n'est pas une valeur autorisée"
       else:
          try:
             for val in lval:
@@ -259,7 +260,7 @@ class MCSIMP(I_OBJECT.OBJECT):
           for val in new_valeur:
               self.typeProto.adapt(val)
               self.intoProto.adapt(val)
-              #on ne verifie pas la cardinalit
+              #on ne verifie pas la cardinalité
               if self.definition.validators:
                   validite=self.definition.validators.valide_liste_partielle(new_valeur)
       except ValError,e:
@@ -289,8 +290,8 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def eval_valeur(self,new_valeur):
     """
-        Essaie d'valuer new_valeur comme une SD, une dclaration Python 
-        ou un EVAL: Retourne la valeur value (ou None) et le test de russite (1 ou 0)
+        Essaie d'évaluer new_valeur comme une SD, une déclaration Python 
+        ou un EVAL: Retourne la valeur évaluée (ou None) et le test de réussite (1 ou 0)
     """
     sd = self.jdc.get_sd_avant_etape(new_valeur,self.etape)
     #sd = self.jdc.get_contexte_avant(self.etape).get(new_valeur,None)
@@ -380,7 +381,7 @@ class MCSIMP(I_OBJECT.OBJECT):
         Inputs :
            - sd=concept detruit
         Fonction :
-        Met a jour la valeur du mot cle simple suite  la disparition 
+        Met a jour la valeur du mot cle simple suite a la disparition 
         du concept sd
         Attention aux matrices
     """
@@ -413,7 +414,7 @@ class MCSIMP(I_OBJECT.OBJECT):
   def replace_concept(self,old_sd,sd):
     """
         Inputs :
-           - old_sd=concept remplac
+           - old_sd=concept remplacé
            - sd=nouveau concept
         Fonction :
         Met a jour la valeur du mot cle simple suite au remplacement 
@@ -442,25 +443,25 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def set_valeur_co(self,nom_co):
       """
-          Affecte  self l'objet de type CO et de nom nom_co
+          Affecte a self l'objet de type CO et de nom nom_co
       """
       #print "set_valeur_co",nom_co
       step=self.etape.parent
       if nom_co == None or nom_co == '':
          new_objet=None
       else:
-         # Avant de crer un concept il faut s'assurer du contexte : step 
+         # Avant de créer un concept il faut s'assurer du contexte : step 
          # courant
          sd= step.get_sd_autour_etape(nom_co,self.etape,avec='oui')
          if sd:
-            # Si un concept du meme nom existe deja dans la porte de l'tape
-            # on ne cre pas le concept
+            # Si un concept du meme nom existe deja dans la portée de l'étape
+            # on ne crée pas le concept
             return 0,"un concept de meme nom existe deja"
-         # Il n'existe pas de concept de meme nom. On peut donc le crer 
-         # Il faut nanmoins que la mthode NommerSdProd de step gre les 
+         # Il n'existe pas de concept de meme nom. On peut donc le créer 
+         # Il faut néanmoins que la méthode NommerSdProd de step gère les 
          # contextes en mode editeur
-         # Normalement la mthode  du Noyau doit etre surcharge
-         # On dclare l'tape du mot cl comme etape courante pour NommerSdprod
+         # Normalement la méthode  du Noyau doit etre surchargée
+         # On déclare l'étape du mot clé comme etape courante pour NommerSdprod
          cs= CONTEXT.get_current_step()
          CONTEXT.unset_current_step()
          CONTEXT.set_current_step(step)
@@ -477,12 +478,12 @@ class MCSIMP(I_OBJECT.OBJECT):
       self.fin_modif()
       step.reset_context()
       #print "set_valeur_co",new_objet
-      return 1,"Concept cr"
+      return 1,"Concept créé"
         
   def verif_existence_sd(self):
      """
-        Vrifie que les structures de donnes utilises dans self existent bien dans le contexte
-        avant tape, sinon enlve la rfrence  ces concepts
+        Vérifie que les structures de données utilisées dans self existent bien dans le contexte
+        avant étape, sinon enlève la référea ces concepts
      """
      #print "verif_existence_sd"
      # Attention : possible probleme avec include
@@ -517,7 +518,7 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def get_type(self):
      """
-     Retourne le type attendu par le mot-cl simple
+     Retourne le type attendu par le mot-clé simple
      """
      return self.definition.type
 
@@ -533,7 +534,7 @@ class MCSIMP(I_OBJECT.OBJECT):
 
   def update_mc_global(self):
      """
-        Met a jour les mots cles globaux enregistrs dans l'tape parente
+        Met a jour les mots cles globaux enregistrés dans l'étape parente
         et dans le jdc parent.
         Un mot cle simple peut etre global. 
      """
@@ -552,14 +553,14 @@ class MCSIMP(I_OBJECT.OBJECT):
      return 0
 
   def valide_item(self,item):
-      """Valide un item isol. Cet item est candidat  l'ajout  la liste existante"""
+      """Valide un item isolé. Cet item est candidata l'ajout a la liste existante"""
       valid=1
       try:
           #on verifie le type
           self.typeProto.adapt(item)
           #on verifie les choix possibles
           self.intoProto.adapt(item)
-          #on ne verifie pas la cardinalit
+          #on ne verifie pas la cardinalité
           if self.definition.validators:
               valid=self.definition.validators.verif_item(item)
       except ValError,e:
@@ -574,7 +575,7 @@ class MCSIMP(I_OBJECT.OBJECT):
           self.typeProto.adapt(item)
           #on verifie les choix possibles
           self.intoProto.adapt(item)
-          #on ne verifie pas la cardinalit mais on verifie les validateurs
+          #on ne verifie pas la cardinalité mais on verifie les validateurs
           if self.definition.validators:
               valid=self.definition.validators.verif_item(item)
           comment=""
