@@ -21,9 +21,15 @@
 #    permet de lancer  EFICAS en n affichant rien
 
 class QWParentSSIhm:
-   def __init__(self,code,appliEficas,version_code):
+   def __init__(self,code,appliEficas,version_code,ssCode=None):
         self.ihm="QT"
         self.code=code
         self.version_code=version_code
+        self.ssCode=ssCode
+        if ssCode != None :
+           self.format_fichier= ssCode  #par defaut
+           #prefsCode.NAME_SCHEME=ssCode
+        else :
+           self.format_fichier="python" #par defaut
         self.appliEficas=appliEficas
 
