@@ -1,29 +1,29 @@
-#@ MODIF N_MCCOMPO Noyau  DATE 07/09/2009   AUTEUR COURTOIS M.COURTOIS 
+#@ MODIF N_MCCOMPO Noyau  DATE 30/08/2011   AUTEUR COURTOIS M.COURTOIS 
 # -*- coding: iso-8859-1 -*-
 # RESPONSABLE COURTOIS M.COURTOIS
 #            CONFIGURATION MANAGEMENT OF EDF VERSION
 # ======================================================================
-# COPYRIGHT (C) 1991 - 2002  EDF R&D                  WWW.CODE-ASTER.ORG
+# COPYRIGHT (C) 1991 - 2011  EDF R&D                  WWW.CODE-ASTER.ORG
 # THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
 # IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
-# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR   
-# (AT YOUR OPTION) ANY LATER VERSION.                                 
+# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
+# (AT YOUR OPTION) ANY LATER VERSION.
+#
+# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
+# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
+# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
+# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
+#
+# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
+# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
+#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
 #
-# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT 
-# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF          
-# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU    
-# GENERAL PUBLIC LICENSE FOR MORE DETAILS.                            
 #
-# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE   
-# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,       
-#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.      
-#                                                                       
-#                                                                       
 # ======================================================================
 
 
-""" 
-    Ce module contient la classe MCCOMPO qui sert  factoriser les comportements 
+"""
+    Ce module contient la classe MCCOMPO qui sert  factoriser les comportements
     des OBJECT composites
 """
 
@@ -33,11 +33,11 @@ import N_OBJECT
 class MCCOMPO(N_OBJECT.OBJECT):
    """
       Classe support d'un OBJECT composite
-  
+
    """
 
    def build_mc(self):
-      """ 
+      """
           Construit la liste des sous-entites du MCCOMPO
            partir du dictionnaire des arguments (valeur)
       """
@@ -66,7 +66,7 @@ class MCCOMPO(N_OBJECT.OBJECT):
           # si une valeur existe dans args ou est obligatoire (generique si toutes les
           # entites ont l attribut statut )
           #
-          objet=self.definition.entites[k](val=args.get(k,None),nom=k,parent=self)
+          objet=v(val=args.get(k,None),nom=k,parent=self)
           mc_liste.append(objet)
           # Si l'objet a une position globale on l'ajoute aux listes correspondantes
           if hasattr(objet.definition,'position'):
@@ -77,7 +77,8 @@ class MCCOMPO(N_OBJECT.OBJECT):
         if args.has_key(k):
            del args[k]
 
-      # Phase 1.2 : on traite les autres entites que SIMP 
+      # Phase 1.2 : on traite les autres entites que SIMP
+      # (FACT en fait car un BLOC ne peut avoir le meme nom qu'un mot-clef)
       for k,v in self.definition.entites.items():
         if v.label == 'SIMP':continue
         if args.has_key(k) or v.statut=='o' :
@@ -86,7 +87,7 @@ class MCCOMPO(N_OBJECT.OBJECT):
           # si une valeur existe dans args ou est obligatoire (generique si toutes les
           # entites ont l attribut statut )
           #
-          objet=self.definition.entites[k](val=args.get(k,None),nom=k,parent=self)
+          objet=v(val=args.get(k,None),nom=k,parent=self)
           mc_liste.append(objet)
         if args.has_key(k):
            del args[k]
@@ -116,7 +117,7 @@ class MCCOMPO(N_OBJECT.OBJECT):
 
       # On conserve les arguments superflus dans l'attribut reste_val
       self.reste_val=args
-      # On ordonne la liste ainsi cre suivant l'ordre du catalogue 
+      # On ordonne la liste ainsi cre suivant l'ordre du catalogue
       # (utile seulement pour IHM graphique)
       mc_liste = self.ordonne_liste(mc_liste)
       # on retourne la liste ainsi construite
@@ -135,28 +136,28 @@ class MCCOMPO(N_OBJECT.OBJECT):
          return mc_liste
 
    def cree_dict_valeurs(self,liste=[],condition=0):
-      """ 
+      """
         Cette mthode cre un contexte (sous la forme d'un dictionnaire)
          partir des valeurs des mots cls contenus dans l'argument liste.
-        L'opration consiste  parcourir la liste (d'OBJECT) et  la 
+        L'opration consiste  parcourir la liste (d'OBJECT) et  la
         transformer en un dictionnaire dont les cls sont les noms des
         mots cls et les valeurs dpendent du type d'OBJECT.
         Ce dictionnaire servira de liste d'arguments d'appel pour les
         fonctions sd_prod de commandes et ops de macros ou de contexte
         d'valuation des conditions de prsence de BLOC.
 
-        Si l'argument condition de la mthode vaut 1, on ne 
+        Si l'argument condition de la mthode vaut 1, on ne
         remonte pas les valeurs des mots cls contenus dans des blocs
         pour eviter les bouclages.
 
-        Cette mthode ralise les oprations suivantes en plus de transformer 
+        Cette mthode ralise les oprations suivantes en plus de transformer
         la liste en dictionnaire :
 
            - ajouter tous les mots-cls non prsents avec la valeur None
-           - ajouter tous les mots-cls globaux (attribut position = 'global' 
+           - ajouter tous les mots-cls globaux (attribut position = 'global'
              et 'global_jdc')
 
-        L'argument liste est, en gnral, une mc_liste en cours de 
+        L'argument liste est, en gnral, une mc_liste en cours de
         construction, contenant les mots-cls locaux et les blocs dj crs.
 
       """
@@ -167,16 +168,22 @@ class MCCOMPO(N_OBJECT.OBJECT):
            # reprsentatif du contexte. Les blocs sont retourns par get_valeur
            # sous la forme d'un dictionnaire : les mots-cls fils de blocs sont
            # donc remonts au niveau du contexte.
-           if not condition:dico.update(v.get_valeur())
+           if not condition:
+               dadd = v.get_valeur()
+               assert intersection_vide(dico, dadd)
+               dico.update(dadd)
         else:
+           assert not dico.has_key(v.nom), "deja vu : %s" % v.nom
            dico[v.nom]=v.get_valeur()
 
-      # On rajoute tous les autres mots-cls locaux possibles avec la valeur 
+      # On rajoute tous les autres mots-cls locaux possibles avec la valeur
       # par dfaut ou None
       # Pour les mots-cls facteurs, on ne traite que ceux avec statut dfaut ('d')
       # et cach ('c')
       # On n'ajoute aucune information sur les blocs. Ils n'ont pas de dfaut seulement
       # une condition.
+      #XXX remplacer le not has_key par un dico diffrent et faire dico2.update(dico)
+      #    ce n'est qu'un pb de perf
       for k,v in self.definition.entites.items():
         if not dico.has_key(k):
            if v.label == 'SIMP':
@@ -215,7 +222,7 @@ class MCCOMPO(N_OBJECT.OBJECT):
       return dico
 
    def recherche_mc_globaux(self):
-      """ 
+      """
           Retourne la liste des mots-cls globaux de l'tape  laquelle appartient self
           et des mots-cls globaux du jdc
       """
@@ -224,7 +231,7 @@ class MCCOMPO(N_OBJECT.OBJECT):
         dict_mc_globaux_fac = self.recherche_mc_globaux_facultatifs()
         for k,v in etape.mc_globaux.items():
            dict_mc_globaux_fac[k]=v.get_valeur()
-        if self.jdc : 
+        if self.jdc :
            for k,v in self.jdc.mc_globaux.items():
               dict_mc_globaux_fac[k]=v.get_valeur()
         return dict_mc_globaux_fac
@@ -232,9 +239,10 @@ class MCCOMPO(N_OBJECT.OBJECT):
         return {}
 
    def recherche_mc_globaux_facultatifs(self):
-      """ 
+      """
           Cette mthode interroge la dfinition de self et retourne la liste des mots-cls fils
-          directs de self de type 'global'
+          directs de self de type 'global'.
+          position='global' n'est donc possible (et n'a de sens) qu'au plus haut niveau.
       """
       dico={}
       etape = self.get_etape()
@@ -248,7 +256,7 @@ class MCCOMPO(N_OBJECT.OBJECT):
       return dico
 
    def supprime(self):
-      """ 
+      """
          Mthode qui supprime toutes les rfrences arrires afin que l'objet puisse
          etre correctement dtruit par le garbage collector
       """
@@ -264,8 +272,8 @@ class MCCOMPO(N_OBJECT.OBJECT):
 
    def get_mocle(self,key):
       """
-          Retourne la valeur du sous mot-cl key 
-          Ce sous mot-cl peut exister, avoir une valeur par defaut ou etre 
+          Retourne la valeur du sous mot-cl key
+          Ce sous mot-cl peut exister, avoir une valeur par defaut ou etre
           dans un BLOC fils de self
       """
       # on cherche dans les mots cles presents, le mot cle de nom key
@@ -297,7 +305,7 @@ class MCCOMPO(N_OBJECT.OBJECT):
         if not mc.isBLOC() : continue
         try:
           return mc.get_mocle(key)
-        except: 
+        except:
           # On n a rien trouve dans ce bloc, on passe au suivant
           pass
       #  On a rien trouve, le mot cle est absent.
@@ -305,10 +313,10 @@ class MCCOMPO(N_OBJECT.OBJECT):
       raise IndexError,"Le mot cle %s n existe pas dans %s" % (key,self)
 
    def get_child(self,name,restreint = 'non'):
-      """ 
+      """
           Retourne le fils de self de nom name ou None s'il n'existe pas
           Si restreint vaut oui : ne regarde que dans la mc_liste
-          Si restreint vaut non : regarde aussi dans les entites possibles 
+          Si restreint vaut non : regarde aussi dans les entites possibles
           avec defaut (Ce dernier cas n'est utilis que dans le catalogue)
       """
       for v in self.mc_liste:
@@ -333,8 +341,8 @@ class MCCOMPO(N_OBJECT.OBJECT):
         etape.mc_globaux[nom]=mc
 
    def append_mc_global_jdc(self,mc):
-      """ 
-          Ajoute le mot-cl mc  la liste des mots-cls globaux du jdc 
+      """
+          Ajoute le mot-cl mc  la liste des mots-cls globaux du jdc
       """
       nom = mc.nom
       self.jdc.mc_globaux[nom]=mc
@@ -368,9 +376,9 @@ class MCCOMPO(N_OBJECT.OBJECT):
         mocle.reparent(self)
 
    def get_sd_utilisees(self):
-      """ 
+      """
         Retourne la liste des concepts qui sont utiliss  l'intrieur de self
-        ( comme valorisation d'un MCS) 
+        ( comme valorisation d'un MCS)
       """
       l=[]
       for child in self.mc_liste:
@@ -378,13 +386,13 @@ class MCCOMPO(N_OBJECT.OBJECT):
       return l
 
    def get_sd_mcs_utilisees(self):
-      """ 
+      """
           Retourne la ou les SD utilise par self sous forme d'un dictionnaire :
             - Si aucune sd n'est utilise, le dictionnaire est vide.
             - Sinon, les cls du dictionnaire sont les mots-cls derrire lesquels on
               trouve des sd ; la valeur est la liste des sd attenante.
               Exemple ::
-              
+
                 { 'VALE_F': [ <Cata.cata.para_sensi instance at 0x9419854>,
                               <Cata.cata.para_sensi instance at 0x941a204> ],
                   'MODELE': [<Cata.cata.modele instance at 0x941550c>] }
@@ -399,7 +407,7 @@ class MCCOMPO(N_OBJECT.OBJECT):
 
    def get_mcs_with_co(self,co):
       """
-         Cette methode retourne l'objet MCSIMP fils de self 
+         Cette methode retourne l'objet MCSIMP fils de self
          qui a le concept co comme valeur.
          En principe, elle ne doit etre utilisee que pour les concepts
          instances de la classe CO
@@ -417,3 +425,14 @@ class MCCOMPO(N_OBJECT.OBJECT):
       for child in self.mc_liste:
         l.extend(child.get_all_co())
       return l
+
+
+def intersection_vide(dict1, dict2):
+    """Verification qu'il n'y a pas de cl commune entre 'dict1' et 'dict2'."""
+    sk1 = set(dict1.keys())
+    sk2 = set(dict2.keys())
+    inter = sk1.intersection(sk2)
+    ok = len(inter) == 0
+    if not ok:
+        print 'ERREUR: Mot(s)-clef(s) vu(s) plusieurs fois :', tuple(inter)
+    return ok
