@@ -1,4 +1,4 @@
-#@ MODIF N_VALIDATOR Noyau  DATE 11/05/2010   AUTEUR COURTOIS M.COURTOIS 
+#@ MODIF N_VALIDATOR Noyau  DATE 11/10/2010   AUTEUR COURTOIS M.COURTOIS 
 # -*- coding: iso-8859-1 -*-
 # RESPONSABLE COURTOIS M.COURTOIS
 #            CONFIGURATION MANAGEMENT OF EDF VERSION
@@ -116,6 +116,7 @@ class TypeProtocol(PProtocol):
         self.typ=typ
 
     def default(self,obj,typ):
+
         help = ""
         for type_permis in typ:
             if type_permis == 'R':
@@ -130,7 +131,13 @@ class TypeProtocol(PProtocol):
                 if is_str(obj): return obj
             elif type_permis == 'Fichier' :
                  import os
-                 if os.path.isfile(obj):return obj
+                 if (len(typ) > 2 and typ[2] == "Sauvegarde") or os.path.isfile(obj):
+                     return obj
+                 else : raise ValError("%s n'est pas un fichier valide" % repr(obj))
+            elif type_permis == 'FichierNoAbs' :
+                 import os
+                 if (len(typ) > 2 and typ[2] == "Sauvegarde") or isinstance(obj, type("")):
+                     return obj
                  else : raise ValError("%s n'est pas un fichier valide" % repr(obj))
             elif type(type_permis) == types.ClassType or isinstance(type_permis,type):
                 try:
@@ -568,6 +575,38 @@ class LongStr(ListVal):
              raise ValError("%s n'est pas de la bonne longueur" % repr(valeur))
           return valeur
 
+class OnlyStr(ListVal):
+      """
+          Validateur operationnel
+          Valide que c'est une chaine
+      """
+      def __init__(self):
+          ListVal.__init__(self)
+          self.cata_info=""
+
+      def info(self):
+          return "regarde si c'est une chaine"
+
+      def info_erreur_item(self):
+          return "Ce n'est pas une chain"
+
+      def convert(self,valeur):
+          for val in valeur:
+              v=self.adapt(val)
+          return valeur
+
+      def verif_item(self,valeur):
+          try:
+             self.adapt(valeur)
+             return 1
+          except:
+             return 0
+
+      def default(self,valeur):
+          if not is_str(valeur):
+             raise ValError("%s n'est pas une string" % repr(valeur))
+          return valeur
+
 class OrdList(ListVal):
       """
           Validateur operationnel
@@ -764,6 +803,10 @@ class AndVal(Valid):
                  self.validators.append(FunctionVal(validator))
               else:
                  self.validators.append(validator)
+              if hasattr(validator,'fonctions'):
+                 for fonction in validator.fonctions :
+                    f=getattr(validator,fonction)
+                    setattr(self,fonction,f)
           self.cata_info=""
 
       def info(self):
@@ -1256,12 +1299,14 @@ class VerifTypeTuple(Valid,ListVal) :
 
       def verif_item(self,valeur):
           try :
-		if len(valeur) != len(self.typeDesTuples): return 0
-                for i in range(len(valeur)) :
-                    ok=self.verifType(valeur[i],self.typeDesTuples[i])
-                    if ok!=1 : return 0
-          except :
+             if len(valeur) != len(self.typeDesTuples):
                 return 0
+             for i in range(len(valeur)) :
+                ok=self.verifType(valeur[i],self.typeDesTuples[i])
+                if ok!=1:
+                   return 0
+          except :
+             return 0
           return 1
 
       def verifType(self,valeur,type_permis):
@@ -1281,4 +1326,54 @@ class VerifTypeTuple(Valid,ListVal) :
              for val in liste:
                 if self.verif_item(val)!=1 : return 0
              return 1
+ 
+class VerifExiste(ListVal) :
+      """
+         fonctionne avec into
+         Met une liste  jour selon les mot clefs existant
+         exemple si into = ("A","B","C")
+         si au niveau N du JDC les objets "A" et "C" existe
+         alors la liste des into deviendra ( "A","C")
+
+         niveauVerif est le niveau du JDC dans lequel va s effectuer la verification
+         niveauVerif est defini par rapport au Noeud :
+         exemple niveauVerif = 1 : on verifie les freres
+                 niveauVerif = 2 : on verifie les oncles..
+      """
+      def __init__(self,niveauVerif):
+          ListVal.__init__(self)
+          self.niveauVerif=niveauVerif
+          self.MCSimp=None
+          self.listeDesFreres=()
+          self.fonctions=('verifie_liste','set_MCSimp')
+
+      def is_list(self):
+          return 1
+
+      def verifie_liste(self,liste):
+          self.set_MCSimp(self.MCSimp)
+          for item in liste :
+            if not( item in self.listeDesFreres) : return 0
+          return 1
+
+      def verif_item(self,valeur):
+          self.set_MCSimp(self.MCSimp)
+          if valeur in self.listeDesFreres : return 1
+          return 0
+
+      def set_MCSimp(self, MCSimp) :
+          self.MCSimp=MCSimp
+          k=self.niveauVerif
+          mc=MCSimp
+          while (k != 0) :
+             parent=mc.parent
+             mc=parent
+             k=k-1
+         #on met la liste  jour
+          parent.forceRecalcul=self.niveauVerif
+          self.listeDesFreres=parent.liste_mc_presents()
+
+      def convert_item(self,valeur):
+          if valeur in self.listeDesFreres : return valeur
+          raise ValError(str(valeur)+" n est pas dans " + str(self.listeDesFreres))
 
